# eleven-pp
- Team-eleven's `pip Development Storage``
- The team-eleven's first pypi project. We make several functions for our work
<br>

- View at : https://pypi.org/project/eleven-pp/0.0.0/

### Install

`$ pip install eleven-pp`

- if you already intalled old version, 
`$ pip install --upgrade eleven-pp`

### USE



### DEV

```bash
$ git clone ...
$ cd eleven-pp
$ pdm venv create
$ source .venv/bin/activate
(eleven-pp-3.8) $ pdm install
```

### TEST

```bash
$ pdm add -dG test pytest pytest-cov
$ pytest
$ pytest -s
$ pytest --cov
```

### DEPLOY

```bash
$ pdm publish
```

### how2pr
- https://oss.cashmallow.com/team/how2pr/

### REF
